OC.L10N.register(
    "news",
    {
    "Download" : "பதிவிறக்குக",
    "Close" : "மூடுக",
    "Web address" : "வலைய முகவரி",
    "Folder name" : "கோப்புறை பெயர்",
    "Username" : "பயனாளர் பெயர்",
    "Password" : "கடவுச்சொல்",
    "Credentials" : "சான்று ஆவணங்கள்",
    "Move" : "Move",
    "Share" : "பகிர்வு",
    "Settings" : "அமைப்புகள்",
    "Documentation" : "ஆவணமாக்கல்",
    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
    "Rename" : "பெயர்மாற்றம்",
    "Delete" : "நீக்குக",
    "Previous" : "முன்தைய",
    "by" : "மூலம்",
    "Title" : "தலைப்பு",
    "Refresh" : "மீள் ஏற்றுக"
},
"nplurals=2; plural=(n != 1);");
